% dynare loglinear_Calvo_simul.mod 

//maxit_=100;

//ii = 1;

//for ti = [1^0.25 1.02^0.25 1.03^0.25 1.04^0.25]
@#define ns=1
@#define sectors=1:ns
@#define nth_s="1"

@#for s in sectors
var sa@{s} x@{s} p@{s} psi@{s} phi@{s} ;  
parameters  sh@{s} teta@{s} ;

@#endfor

var sa x w r C N i pi a m cp;
parameters teta aux rgm ALFAI phi_pi phi_y sigma newphi gamma alpha beta epselon chi mu rhom rhoA sss xss rhocp VARUA VARUM VARUCP;
varexo ee uu ucp;

sigma=1;        % elasticity of marginal utility of consumption
newphi=1;       % elasticity of labour supply
gamma=0;      % real wage rigidity parameter
alpha=0;        % decreasing returns to scale parameter Yit = At*Nit^(1-alpha)
beta=0.99;      % subjective discount factor
epselon=10;     % Dixit-Stiglitz elasticity of substitution among goods
chi=0;          % degree of price indexation
mu=0;           % degree of backward looking indexation 

teta1=1;      % Calvo parameter
teta2=0.86;      % Calvo parameter
teta=0.75;

sh1=0.95;
sh2=0.05;

%SHOCKS
rhom = 0.5;       % persistence of the inflation target shock
VARUM = 1; 
rhoA=0.95;       % persistence of technology shock
VARUA = 0.45^2*0;
rhocp=0;      % persistence of cost-push shock
VARUCP = 0;


    


rgm=0.0;

% TAYLOR RULE CALIBRATION
ALFAI=0.0;        % degree of interest rate inertia in Taylor rule

phi_pi=1.5;
phi_y=0.5/4;


aux=1;
xss=1;
sss=1;

% DEFINE: pi = inflation rate; x = ratio between optimal resetted price and the price level = pi*/p


model(linear);

@#for s in sectors

x@{s}=psi@{s}-phi@{s};

psi@{s}=(1-teta@{s}*beta*rgm^epselon)*(w-a+(1-sigma)*C)+(teta@{s}*beta*rgm^(epselon))*(psi@{s}(+1)+(epselon)*pi(+1));
phi@{s}=(1-teta@{s}*beta*rgm^((epselon-1)))*(1-sigma)*C+(teta@{s}*beta*rgm^((epselon-1)))*(phi@{s}(+1)+(epselon-1)*pi(+1));

p@{s}=teta@{s}*(rgm)^(epselon-1)*(p@{s}(-1)-pi)+(1-teta@{s}*(rgm)^(epselon-1))*x@{s};
//(1-teta@{s}*(rgm)^(epselon-1))*x@{s}=teta@{s}*(rgm)^(epselon-1)*(pi);

sa@{s}=(-epselon*(1-teta@{s}*rgm^(epselon)))*x@{s}+((epselon)*teta@{s}*rgm^(epselon))*pi+(teta@{s}*rgm^(epselon))*sa@{s}(-1);

@#endfor



x=(
@#for s in 1:ns
+sh@{s}*x@{s}
@#endfor
);

0=(
@#for s in 1:ns
+sh@{s}*p@{s}
@#endfor
);


C=C(+1)-sigma^(-1)*(i-pi(+1));
w=gamma*w(-1)+(1-gamma)*(newphi*N+sigma*C)+cp;
N=sa+(C-a);


sa=(
@#for s in 1:ns
+sh@{s}*sa@{s}
@#endfor
);

i=i(-1)*ALFAI + (1-ALFAI)*(pi*phi_pi +C*phi_y)+m;
i=r+pi(+1);
a=rhoA*a(-1)+ee;
m=rhom*m(-1)+uu;
cp=rhocp*cp(-1)+ucp;
end;

%OLD VERSION s=(-epselon*(1-teta)*xss^(-epselon)/sss)*x+(-epselon*chi*mu*teta*rgm^(epselon*(1-chi))/(1-alpha))*pi(-1)+(epselon*teta*rgm^(epselon*(1-chi))/(1-alpha))*pi+(teta*rgm^(epselon*(1-chi)))*s(-1);



steady;
check;



options_.qz_criterium = 1+1e-6; //make sure the option is set






stoch_simul(irf=0,nograph,noprint); 

shocks;
var ee; stderr 0.01;
var uu; stderr 0.01;   
var ucp; stderr 0.01;
end;



set_param_value('teta1',0.6);

set_param_value('sh1',1);


set_param_value('rgm',1.0^0.25);

phi_pi_vec=linspace(0,5,200);
    phi_y_vec=linspace(0,5,200);
    [phi_pi_mat,phi_y_mat]=meshgrid(phi_pi_vec,phi_y_vec);
    
        info_mat=NaN(size(phi_pi_mat));
        for phi_pi_iter=1:length(phi_pi_vec)
            for phi_y_iter=1:length(phi_y_vec)
                set_param_value('phi_pi',phi_pi_mat(phi_pi_iter,phi_y_iter));
                set_param_value('phi_y',phi_y_mat(phi_pi_iter,phi_y_iter));
                [dr,info]=resol(0,M_,options_,oo_);
                info_mat(phi_pi_iter,phi_y_iter)=info(1);
            end
        end
        Z_plot=zeros(size(info_mat));
        Z_plot(info_mat==0)=1;
       // figure
        contour(phi_pi_mat,phi_y_mat,Z_plot,1,'Linecolor','k','LineWidth',2)
        xlabel('\phi_\pi')
        ylabel('\phi_y')
      

       
hold on

set_param_value('teta1',0.6);

set_param_value('sh1',1);

set_param_value('rgm',1.02^0.25);

phi_pi_vec=linspace(0,5,200);
    phi_y_vec=linspace(0,5,200);
    [phi_pi_mat,phi_y_mat]=meshgrid(phi_pi_vec,phi_y_vec);
   
        info_mat=NaN(size(phi_pi_mat));
        for phi_pi_iter=1:length(phi_pi_vec)
            for phi_y_iter=1:length(phi_y_vec)
                set_param_value('phi_pi',phi_pi_mat(phi_pi_iter,phi_y_iter));
                set_param_value('phi_y',phi_y_mat(phi_pi_iter,phi_y_iter));
                [dr,info]=resol(0,M_,options_,oo_);
                info_mat(phi_pi_iter,phi_y_iter)=info(1);
            end
        end
        Z_plot=zeros(size(info_mat));
        Z_plot(info_mat==0)=1;
       // figure
        contour(phi_pi_mat,phi_y_mat,Z_plot,1,'Linecolor','r','LineWidth',2)
        xlabel('\phi_\pi')
        ylabel('\phi_y')
       

  
    
hold on

set_param_value('teta1',0.6);

set_param_value('sh1',1);


set_param_value('rgm',1.04^0.25);

phi_pi_vec=linspace(0,5,200);
    phi_y_vec=linspace(0,5,200);
    [phi_pi_mat,phi_y_mat]=meshgrid(phi_pi_vec,phi_y_vec);
    
        info_mat=NaN(size(phi_pi_mat));
        for phi_pi_iter=1:length(phi_pi_vec)
            for phi_y_iter=1:length(phi_y_vec)
                set_param_value('phi_pi',phi_pi_mat(phi_pi_iter,phi_y_iter));
                set_param_value('phi_y',phi_y_mat(phi_pi_iter,phi_y_iter));
                [dr,info]=resol(0,M_,options_,oo_);
                info_mat(phi_pi_iter,phi_y_iter)=info(1);
            end
        end
        Z_plot=zeros(size(info_mat));
        Z_plot(info_mat==0)=1;
       // figure

        contour(phi_pi_mat,phi_y_mat,Z_plot,1,'--','Linecolor','b','LineWidth',2)
        xlabel('\phi_\pi')
        ylabel('\phi_y')
        
        legend({'\pi=0%','\pi=2%','\pi=4%'},'fontsize',14) ;

       
        annotation('textarrow',[0.5 0.7],[0.9 0.8]);

        dim = [0.6 0.45 0.3 0.3];
        str = {'Determinacy regions','shrink more with \pi'};
        annotation('textbox',dim,'String',str,'FitBoxToText','on');
hold off  